#' Read large participant table in chunks
#'
#' @description digi_lime_get_part_chunks()
#'
#' @param surv_id Survey ID
#' @param max_tn Maximum number to participants
#' @param chunk_size Size of a single chunk
#' @param attributes Additional attributes to read
#'
#' @return ...
#' @export
#' @examples
#' digi_lime_get_part_chunks()
#'
digi_lime_get_part_chunks <-
    function(surv_id,
             max_tn,
             chunk_size,
             attributes) {
        seq_vec <- seq(1, max_tn, chunk_size)
        seq_vec %>%
            map_dfr(
                .,
                ~
                    get_participants(
                        iSurveyID = surv_id,
                        iStart = .,
                        iLimit = chunk_size,
                        bUnused = FALSE,
                        aAttributes = attributes
                    )
            ) %>%
            as_tibble() %>%
            distinct() %>%
            filter(!is.na(tid))
    }
